// Copyright 2023-2024 Gentoo Authors
// Distributed under the terms of the GNU General Public License v2

var target = Argument("target", "pack");
var configuration = Argument("configuration", "Release");

var toolArgs = Argument("tool-args", "--global");
var toolInstallArgs = Argument("tool-install-args", $"{toolArgs} --verbosity diagnostic");

var admin = System.IO.Path.GetFullPath("./admin");
var dotnetWrapper = System.IO.Path.Combine(admin, "dotnet_wrapper.sh");

Task("clean")
    .Does(() =>
    {
        StartProcess(dotnetWrapper, new ProcessSettings {
                Arguments = "clean --verbosity quiet"
            });

        StartProcess("rm", new ProcessSettings {
                Arguments = "-f -r .cache/nupkg"
            });
    });

Task("build")
    .Does(() =>
    {
        StartProcess(dotnetWrapper, new ProcessSettings {
                Arguments = $"build --configuration {configuration}"
            });
    });

Task("test")
    .IsDependentOn("build")
    .Does(() =>
    {
        StartProcess(dotnetWrapper, new ProcessSettings {
                Arguments = $"test --configuration {configuration}"
            });
    });

Task("pack")
    .IsDependentOn("build")
    .Does(() =>
    {
        StartProcess(dotnetWrapper, new ProcessSettings {
                Arguments = $"pack --configuration {configuration}"
            });
    });

Task("install")
    .IsDependentOn("pack")
    .Does(() =>
    {
        var tools = new[] {
            "Gdmt.Checkcore",
            "Gdmt.Commit",
            "Gdmt.Ebuild",
            "Gdmt.Genpwsh",
            "Gdmt.Gensdk",
            "Gdmt.Govendor",
            "Gdmt.PackageName",
            "Gdmt.Restore",
            "Gdmt.Sync"
        };

        foreach (var tool in tools)
        {
            Console.WriteLine($"Reinstalling tool: {tool}");

            StartProcess(dotnetWrapper, new ProcessSettings {
                    Arguments = $"tool uninstall {toolArgs} {tool}"
                });

            StartProcess(dotnetWrapper, new ProcessSettings {
                    Arguments = $"tool install --add-source .cache/nupkg {toolInstallArgs} {tool}"
                });
        }
    });

RunTarget(target);
